var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { Fragment, useContext, useEffect, useState, } from 'react';
import AuthContext from './AuthContext';
import OrdersContext from './OrdersContext';
import ConfigContext from './ConfigContext';
import * as orderingCore from '@orderingstack/ordering-core';
import { useModule } from './ModuleContext';
export default function OrderProvider(props) {
    const _configContext = useContext(ConfigContext);
    if (!_configContext) {
        return React.createElement(Fragment, null, "Configuration should be provided");
    }
    const config = _configContext;
    const [orders, setOrders] = useState({ orderRecMap: {}, loaded: false, orders: [] });
    const { authProvider, loggedIn } = useContext(AuthContext);
    const { moduleConfig, onSignOut } = useModule();
    console.log('##### ORDERING-CORE-REACT OrderProvider moduleConfig', moduleConfig);
    console.log('##### ORDERING-CORE-REACT OrderProvider moduleConfig', onSignOut);
    const onOrdersUpdated = (order, allOrders) => {
        //console.log("--------------" + Object.keys(allOrders).length);
        console.log('ordering-core-react orders updated', allOrders);
        setOrders({
            orderRecMap: Object.assign({}, allOrders),
            loaded: true,
            error: undefined,
            orders: Object.values(allOrders).map((rec) => rec.order),
        });
    };
    function setOrderChangesListener(authProvider) {
        return __awaiter(this, void 0, void 0, function* () {
            let disconnect = () => {
                return Promise.resolve();
            };
            try {
                const { token } = yield authProvider();
                if (token) {
                    disconnect = yield orderingCore.orderChangesListener(config.baseUrl, config.tenant, config.venue, authProvider, onOrdersUpdated, () => {
                        setOrders({
                            orderRecMap: {},
                            loaded: false,
                            error: new Error('auth failure'),
                            orders: [],
                        });
                        return Promise.resolve();
                    }, config.enableKDS, props.onWebsocketNotification, props.onSteeringCommand, moduleConfig === null || moduleConfig === void 0 ? void 0 : moduleConfig.id, () => {
                        console.log('##### ORDERING-CORE-REACT MODULECONFIG CALLBACK data OLD');
                    }, () => {
                        console.log('OKOKOKOKOKOK');
                    }, {
                        appInsights: props.appInsights,
                        debugWs: props.debugWs,
                        onlyCompletedOrdersForUser: props.onlyCompletedOrdersForUser,
                        // @ts-ignore
                        onWebsocketConnected: (status) => {
                            var _a;
                            (_a = props.onWebsocketConnected) === null || _a === void 0 ? void 0 : _a.call(props, status);
                        },
                    });
                }
            }
            catch (err) {
                setOrders({ orderRecMap: {}, loaded: false, error: err, orders: [] });
            }
            return disconnect;
        });
    }
    useEffect(() => {
        orderingCore.setOrderStoreUpdatedCallback(onOrdersUpdated);
        const promise = setOrderChangesListener(authProvider);
        return () => {
            promise.then((disconnect) => disconnect());
        };
    }, [loggedIn]);
    return (React.createElement(Fragment, null,
        React.createElement(OrdersContext.Provider, { value: orders }, props.children)));
}
export function useOrdersContext() {
    const context = useContext(OrdersContext);
    if (!context) {
        throw new Error('OrdersContext was used outside of its Provider');
    }
    return context;
}
